<?php
/*
Plugin Name: WP Views Counter
Plugin URI: https://mohamedportfolio.com
Description: إضافة خفيفة لعرض عدد المشاهدات بجانب كل منشور أو صفحة في لوحة التحكم، مع إمكانية التحكم في الإعدادات من لوحة التحكم.
Version: 1.1
Author: Mohamed Shaker
Author URI: https://mohamedportfolio.com
License: GPL2
*/

// تسجيل عدد المشاهدات عند زيارة المنشور
function wvc_track_post_views($post_id) {
    if (!is_single()) return;
    
    $views = get_post_meta($post_id, '_wvc_views', true);
    $views = $views ? $views + 1 : 1;
    update_post_meta($post_id, '_wvc_views', $views);
}
add_action('wp_head', function() {
    if (is_single()) {
        global $post;
        wvc_track_post_views($post->ID);
    }
});

// إضافة إعدادات الإضافة في لوحة التحكم
function wvc_add_settings_menu() {
    add_options_page('إعدادات WP Views Counter', 'WP Views Counter', 'manage_options', 'wvc-settings', 'wvc_render_settings_page');
}
add_action('admin_menu', 'wvc_add_settings_menu');

function wvc_render_settings_page() {
    ?>
    <div class="wrap">
        <h1>إعدادات WP Views Counter</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('wvc_settings_group');
            do_settings_sections('wvc-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function wvc_register_settings() {
    register_setting('wvc_settings_group', 'wvc_show_in_admin');
    register_setting('wvc_settings_group', 'wvc_show_in_frontend');

    add_settings_section('wvc_main_section', 'إعدادات العرض', null, 'wvc-settings');

    add_settings_field('wvc_show_in_admin', 'عرض المشاهدات في لوحة التحكم', 'wvc_show_in_admin_callback', 'wvc-settings', 'wvc_main_section');
    add_settings_field('wvc_show_in_frontend', 'عرض المشاهدات في الواجهة الأمامية', 'wvc_show_in_frontend_callback', 'wvc-settings', 'wvc_main_section');
}
add_action('admin_init', 'wvc_register_settings');

function wvc_show_in_admin_callback() {
    $value = get_option('wvc_show_in_admin', 'yes');
    echo '<input type="checkbox" name="wvc_show_in_admin" value="yes" ' . checked($value, 'yes', false) . ' />';
}

function wvc_show_in_frontend_callback() {
    $value = get_option('wvc_show_in_frontend', 'no');
    echo '<input type="checkbox" name="wvc_show_in_frontend" value="yes" ' . checked($value, 'yes', false) . ' />';
}

// إضافة عمود جديد لعرض عدد المشاهدات في لوحة التحكم
function wvc_add_views_column($columns) {
    if (get_option('wvc_show_in_admin', 'yes') === 'yes') {
        $columns['wvc_views'] = (get_locale() == 'ar' ? 'المشاهدات' : 'Views');
    }
    return $columns;
}
add_filter('manage_posts_columns', 'wvc_add_views_column');
add_filter('manage_pages_columns', 'wvc_add_views_column');

// عرض عدد المشاهدات في العمود الجديد
function wvc_display_views_column($column, $post_id) {
    if ($column === 'wvc_views') {
        echo get_post_meta($post_id, '_wvc_views', true) ?: '0';
    }
}
add_action('manage_posts_custom_column', 'wvc_display_views_column', 10, 2);
add_action('manage_pages_custom_column', 'wvc_display_views_column', 10, 2);

// عرض عدد المشاهدات في الواجهة الأمامية
function wvc_display_views_in_frontend($content) {
    if (is_single() && get_option('wvc_show_in_frontend', 'no') === 'yes') {
        global $post;
        $views = get_post_meta($post->ID, '_wvc_views', true) ?: '0';
        $content .= '<p><strong>' . __('عدد المشاهدات:', 'wvc') . '</strong> ' . $views . '</p>';
    }
    return $content;
}
add_filter('the_content', 'wvc_display_views_in_frontend');

// إعادة تعيين المشاهدات عند تحديث المنشور
function wvc_reset_views_on_update($post_id) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return;
    delete_post_meta($post_id, '_wvc_views');
}
add_action('save_post', 'wvc_reset_views_on_update');

// حذف عدد المشاهدات عند حذف المنشور
function wvc_delete_views_on_delete($post_id) {
    delete_post_meta($post_id, '_wvc_views');
}
add_action('delete_post', 'wvc_delete_views_on_delete');
